@@ -196,6 +196,20 @@ ragged2 = VectorOfArray([[1.0, 2.0, 3.0, 4.0], [5.0, 6.0], [7.0, 8.0, 9.0]])
 @test ragged2[1:(end - 1), 2] == [5.0]
 @test ragged2[1:(end - 1), 3] == [7.0, 8.0]
 
+# Test that RaggedEnd and RaggedRange broadcast as scalars
+# (fixes issue with SymbolicIndexingInterface where broadcasting over RaggedEnd would fail)
+ragged_idx = lastindex(ragged, 1)
+@test ragged_idx isa RecursiveArrayTools.RaggedEnd
+@test Base.broadcastable(ragged_idx) isa Ref
+# Broadcasting with RaggedEnd should not error
+@test identity.(ragged_idx) === ragged_idx
+
+ragged_range_idx = 1:lastindex(ragged, 1)
+@test ragged_range_idx isa RecursiveArrayTools.RaggedRange
+@test Base.broadcastable(ragged_range_idx) isa Ref
+# Broadcasting with RaggedRange should not error
+@test identity.(ragged_range_idx) === ragged_range_idx
+
 # Broadcasting of heterogeneous arrays (issue #454)
 u = VectorOfArray([[1.0], [2.0, 3.0]])
 @test length(view(u, :, 1)) == 1
@@ -220,8 +234,8 @@ u[1, [1, 3], 2] .= [7.0, 9.0]
 
 # 3D inner arrays (tensors) with ragged third dimension
 u = VectorOfArray([zeros(2, 1, n) for n in (2, 3)])
-@test size(view(u,:,:,:,1)) == (2, 1, 2)
-@test size(view(u,:,:,:,2)) == (2, 1, 3)
+@test size(view(u, :, :, :, 1)) == (2, 1, 2)
+@test size(view(u, :, :, :, 2)) == (2, 1, 3)
 # assign into a slice of the second inner array using last index Int
 u[2, 1, :, 2] .= [7.0, 8.0, 9.0]
 @test vec(u.u[2][2, 1, :]) == [7.0, 8.0, 9.0]
