@@ -132,6 +132,23 @@ y = ArrayPartition(ArrayPartition([1], [2.0]), ArrayPartition([3], [4.0]))
 @inferred recursive_one(x)
 @inferred recursive_bottom_eltype(x)
 
+src_voa = VectorOfArray([[1.0, 2.0], [3.0, 4.0]])
+src_ap = ArrayPartition(src_voa)
+
+copied_ap = recursivecopy(src_ap)
+@test copied_ap.x[1].u[1] == src_ap.x[1].u[1]
+@test copied_ap.x[1].u[2] == src_ap.x[1].u[2]
+@test copied_ap.x[1].u[1] !== src_ap.x[1].u[1]
+@test copied_ap.x[1].u[2] !== src_ap.x[1].u[2]
+
+dest_voa = VectorOfArray([zeros(2), zeros(2)])
+dest_ap = ArrayPartition(dest_voa)
+recursivecopy!(dest_ap, src_ap)
+@test dest_ap.x[1].u[1] == src_ap.x[1].u[1]
+@test dest_ap.x[1].u[2] == src_ap.x[1].u[2]
+@test dest_ap.x[1].u[1] !== src_ap.x[1].u[1]
+@test dest_ap.x[1].u[2] !== src_ap.x[1].u[2]
+
 # mapreduce
 @inferred Union{Int, Float64} sum(x)
 @inferred sum(ArrayPartition(ArrayPartition(zeros(4, 4))))
@@ -149,7 +166,7 @@ y = ArrayPartition(ArrayPartition([1], [2.0]), ArrayPartition([3], [4.0]))
 @test any(isnan, ArrayPartition([2], [NaN]))
 @test any(isnan, ArrayPartition([2], ArrayPartition([NaN])))
 
-# all 
+# all
 @test !all(isnan, ArrayPartition([1, 2], [3.0, 4.0]))
 @test !all(isnan, ArrayPartition([3.0, 4.0]))
 @test !all(isnan, ArrayPartition([NaN], [3.0, 4.0]))
@@ -312,13 +329,13 @@ end
 end
 
 # Test adapt on ArrayPartition from Float64 to Float32 arrays
-a = Float64.([1., 2., 3., 4.])
-b = Float64.([1., 2., 3., 4.])
+a = Float64.([1.0, 2.0, 3.0, 4.0])
+b = Float64.([1.0, 2.0, 3.0, 4.0])
 part_a_64 = ArrayPartition(a, b)
 part_a = adapt(Array{Float32}, part_a_64)
 
-c = Float32.([1., 2., 3., 4.])
-d = Float32.([1., 2., 3., 4.])
+c = Float32.([1.0, 2.0, 3.0, 4.0])
+d = Float32.([1.0, 2.0, 3.0, 4.0])
 part_b = ArrayPartition(c, d)
 
 @test part_a == part_b # Test equality of partitions
@@ -328,4 +345,4 @@ for i in 1:length(part_a.x)
     sub_b = part_b.x[i]
     @test sub_a == sub_b # Test for value equality
     @test typeof(sub_a) === typeof(sub_b) # Test type equality
-end
\ No newline at end of file
+end
